<template>
  <div>
    <el-dialog
      :title="title"
      :visible="visible"
      :before-close="handleClose"
      :close-on-click-modal="false"
      width="60%"
      top="5vh"
    >
      <el-form ref="formInfo" :model="parameter" :rules="rules">
        <el-row>
          <el-table
            :data="parameter.pilotSpecificScheduleList"
            size="mini"
            :header-cell-style="{
              'text-align': 'center'
            }"
            class="my-el-table"
          >
            <el-table-column width="55" align="center" v-if="!disabled">
              <template
                slot="header"
                v-if="!parameter.pilotSpecificScheduleList.length"
              >
                <i
                  class="el-icon-plus add-btn"
                  @click="tableAdd('pilotSpecificScheduleList')"
                />
              </template>
              <template slot-scope="scope">
                <i
                  class="el-icon-plus add-btn"
                  @click="tableAdd('pilotSpecificScheduleList')"
                ></i>
                <i
                  v-if="parameter.pilotSpecificScheduleList.length >= 2"
                  class="el-icon-delete del-btn"
                  @click="tableDel('pilotSpecificScheduleList', scope.row)"
                />
              </template>
            </el-table-column>
            <el-table-column
              type="index"
              label="序号"
              align="center"
            ></el-table-column>
            <el-table-column
              prop="planYear"
              width="100"
              label="计划年度"
              align="center"
            >
              <template v-slot="{row}" v-if="!disabled">
                <el-date-picker
                  v-model="row.planYear"
                  style="width: 100%"
                  type="year"
                  value-format="yyyy"
                  :disabled="disabled"
                  format="yyyy"
                  placeholder="选择计划年度"
                >
                </el-date-picker>
              </template>
            </el-table-column>
            <el-table-column
              prop="planMonth"
              width="100"
              label="计划月度"
              align="center"
            >
              <template v-slot="{row}" v-if="!disabled">
                <el-date-picker
                  v-model="row.planMonth"
                  style="width: 100%"
                  type="month"
                  value-format="M"
                  format="M"
                  :disabled="disabled"
                  placeholder="请选择计划月度"
                >
                </el-date-picker>
              </template>
            </el-table-column>
            <el-table-column prop="planType" width="140" label="计划类型">
              <template slot-scope="scope" >
                <el-form-item
                 
                  :prop="`pilotSpecificScheduleList[${scope.$index}].planType`"
                  :rules="rules.planType"
                >
                  <dict-select
                  v-if="!disabled"
                    dictCode="jhlx"
                    :hasDefaultOption="true"
                    clearable
                    v-model="scope.row.planType"
                    placeholder="请选择计划类型"
                  />
                   <div style="text-align: center;" v-else>{{getDictName('jhlx',scope.row.planType)}}</div>
                </el-form-item>
               
              </template>
            </el-table-column>
            <el-table-column prop="planContent" label="计划内容">
              <template slot-scope="scope" >
                <el-form-item
                  :prop="
                    `pilotSpecificScheduleList[${scope.$index}].planContent`
                  "
                  :rules="rules.planContent"
                >
                  <el-input
                  v-if="!disabled"
                    v-model.trim="scope.row.planContent"
                    type="textarea"
                  />
                  <div style="text-align: center;" v-else> {{scope.row.planContent}}</div>
                </el-form-item>

              </template>
            </el-table-column>
          </el-table>
        </el-row>
      </el-form>
      <span slot="footer" class="dialog-footer">
        <el-button
          v-if="!disabled"
          type="primary"
          @click="handleSave"
          :loading="saveloading"
          >确认
        </el-button>
        <el-button @click="handleClose">取消</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import org from '@/api/org.js'
import utils from '@/utils.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import measureIterationApplication from '@/api/projectActionIteration/measureIterationApplication.js'
import majorProjects from '@/api/MajorReformProjects/majorProjects.js'
import moment from 'moment'
import {TableMixin} from '@/mixins/tableMixin'
export default {
  name: 'ApplyForDialog',
   mixins: [TableMixin],
  data() {
    return {
      activeCollapse1: '1',
      visible: false,
      title: '月度计划',
      disabled: false,
      index: null,
      saveloading: false,
      rules: {
        planContent: [
          {
            required: true,
            // message: '请输入具体举措',
            trigger: 'change'
          }
        ],
        planType: [
          {
            required: true,
            // message: '请输入具体举措',
            trigger: 'change'
          }
        ]
      },
      queryParam: {
        pageBean: {
          page: 1,
          pageSize: -1
        }
      },
      parameter: {
        pilotSpecificScheduleList: []
      },
      JCIndex: null,
      JCItem: null,
      iterationType: 0
    }
  },
  created() {},
  mounted() {},
  methods: {
    open(JCItem, JCIndex, iterationType) {
      //   console.log(JCItem)
      if (JCItem.pilotSpecificScheduleList) {
        let tempData = utils.deepClone(JCItem.pilotSpecificScheduleList)
        tempData.forEach(item => {
          item.planYear = item.planYear.toString()
          item.planMonth = item.planMonth.toString()
        })
        this.parameter.pilotSpecificScheduleList = tempData
      } else {
        if (JCItem.id) {
          let data = {
            pageBean: {
              page: 1,
              pageSize: -1
            },
            querys: [
              {
                group: 'main',
                operation: 'EQUAL',
                parentGroup: '',
                property: 'MEASURES_ID_',
                relation: 'AND',
                value: JCItem.id
              }
            ]
          }
          measureIterationApplication.getMonthDetails(data, res => {
            if (res.rows.length) {
              res.rows.forEach(item => {
                item.planYear = item.planYear.toString()
                item.planMonth = item.planMonth.toString()
              })
              this.$set(this.parameter, 'pilotSpecificScheduleList', res.rows)
              console.log(this.parameter);
            }
          })
        }
      }
      //   console.log(
      //     this.parameter.pilotSpecificScheduleList,
      //     'this.parameter.pilotSpecificScheduleList.............'
      //   )
      this.visible = true
      this.JCIndex = JCIndex
      this.JCItem = JCItem
      this.iterationType = iterationType
      if (this.iterationType == 'detail') {
        this.disabled = true
      } else {
        this.disabled = false
      }
    },
    tableAdd(type) {
      length = this.parameter.pilotSpecificScheduleList.length
      this.parameter.pilotSpecificScheduleList.push({
        key: length + new Date(),
        planYear: moment().format('YYYY'),
        planMonth: moment().format('M'),
        progressStatus: 1,
        planType: '',
        planContent: ''
      })
    },
    tableDel(type, row) {
      if (!row.id) {
        this.parameter.pilotSpecificScheduleList = this.parameter.pilotSpecificScheduleList.filter(
          item => item.key !== row.key
        )
      } else {
        console.log(type)
        this.$confirm('确认删除这条记录？', '提示', {
          cancelButtonText: '关闭',
          type: 'error'
        }).then(() => {
          majorProjects.deleteJdjh(row.id, res => {
            if (res.state) {
              this.$message.success('删除数据成功')
              this.parameter[type] = this.parameter[type].filter(
                item => item.id !== row.id
              )
            }
          })
        })
      }
    },
    // 关闭新增人员窗口
    handleClose() {
      this.visible = false
      this.saveloading = false
      this.disabled = false
      this.parameter = {
        pilotSpecificScheduleList: []
      }
    },

    add(val) {
      this.title = '新增'
      this.visible = true
      this.parameter.projectId = val
      this.parameter.iteration = 0
    },
    edit(val, index, active) {
      this.index = index
      this.title = '编辑'
      this.visible = true
      this.parameter = {
        ...val,
        edit: true,
        iteration: active == 0 ? 0 : 1
      }
    },
    getParentsById(list, id) {
      console.log(111)
      for (let i in list) {
        if (list[i].id == id) {
          //这里的no根据你的需求可进行改变
          //查询到就返回该数组对象的value
          return [list[i].id]
        }
        if (list[i].children) {
          let node = this.getParentsById(list[i].children, id)
          if (node !== undefined) {
            //查询到把父节把父节点加到数组前面
            node.unshift(list[i].id)
            console.log(node)
            return node
          }
        }
      }
    },

    changeUnit(value) {
      let nodesObj = this.$refs['cascader'].getCheckedNodes()
      if (nodesObj != []) {
        this.parameter.unitId = nodesObj[0].data.id
        this.parameter.unitName = nodesObj[0].label
        this.parameter.unitCode = nodesObj[0].data.code
        this.parameter.unitGrade = nodesObj[0].level
      } else {
        this.parameter.unitId = ''
        this.parameter.unitName = ''
        this.parameter.unitCode = ''
        this.parameter.unitGrade = ''
      }
    },
    // 保存
    handleSave() {
      if (this.parameter.pilotSpecificScheduleList.length) {
        this.$refs.formInfo.validate(valid => {
          if (valid) {
            console.log(this.parameter.pilotSpecificScheduleList)
            this.JCItem.pilotSpecificScheduleList = utils.deepClone(
              this.parameter.pilotSpecificScheduleList
            )
            this.JCItem.edit = true
            this.JCItem.pilotSpecificScheduleList.forEach(item => {
              delete item.key
              if (this.JCItem.id) {
                item.measuresId = this.JCItem.id
              }
            })
            this.parameter.pilotSpecificScheduleList = []
            this.$emit(
              'getData',
              this.JCItem,
              this.JCIndex - 0,
              this.iterationType
            )
            this.handleClose()
          }
        })
      }

      // this.saveloading=true
      // if (this.title == '新增') {
      //     this.$emit('getData', this.parameter)
      // } else {
      //     this.$emit('getData', this.parameter, this.index)
      // }

      // this.$refs.formInfo.validate((valid) => {
      // 	if (valid) {
      // 		if (this.title === '添加' || this.title === 'add') {
      // 			measureIterationApplication.addData(this.parameter, (res) => {
      // 				if (res.state) {
      // 					this.$notify({
      // 						type: 'success',
      // 						message: '添加成功',
      // 						duration: 2000,
      // 					})
      // 					this.$emit('getData')
      // 					this.handleClose()
      // 				}
      // 			})
      // 		} else if (this.title === '编辑' || this.title === 'edit') {
      // 			measureIterationApplication.editData(this.parameter, (res) => {
      // 				if (res.state) {
      // 					this.$notify({
      // 						type: 'success',
      // 						message: '修改成功',
      // 						duration: 2000,
      // 					})
      // 					this.$emit('getData')
      // 					this.handleClose()
      // 				}
      // 			})
      // 		}
      // 	}
      // })
    }
  }
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';

.add-btn {
  font-weight: bold;
  cursor: pointer;
  color: $--color-primary;
}

.del-btn {
  font-weight: bold;
  margin-left: 10px;
  color: $--color-danger;
  cursor: pointer;
}

/deep/.el-dialog__body {
  max-height: 600px;
  overflow-y: auto;
}
.my-el-table {
  /deep/.el-form-item {
    margin-bottom: 0;
  }

  /deep/.el-form-item.is-error {
    margin-bottom: 0;
  }
}
</style>
